@@ -1,15 +1,19 @@
 #' Flatten a list of lists into a simple vector.
 #'
 #' These functions remove a level hierarchy from a list. They are similar to
-#' \code{\link{unlist}}, only ever remove a single layer of hierarchy, and
-#' are type-stable so you always know what the type of the output is.
+#' [unlist()], but they only ever remove a single layer of hierarchy and they
+#' are type-stable, so you always know what the type of the output is.
 #'
 #' @param .x A list of flatten. The contents of the list can be anything for
-#'   \code{flatten} (as a list is returned), but the contents must match the
+#'   `flatten` (as a list is returned), but the contents must match the
 #'   type for the other functions.
-#' @return \code{flatten()} returns a list, \code{flatten_lgl} a logical
-#'   vector, \code{flatten_int} an integer vector, \code{flatten_dbl} a
-#'   double vector, and \code{flatten_chr} a character vector.
+#' @return `flatten()` returns a list, `flatten_lgl()` a logical
+#'   vector, `flatten_int()` an integer vector, `flatten_dbl()` a
+#'   double vector, and `flatten_chr()` a character vector.
+#'
+#'   `flatten_dfr()` and `flatten_dfc()` return data frames created by
+#'   row-binding and column-binding respectively. They require dplyr to
+#'   be installed.
 #' @inheritParams map
 #' @export
 #' @examples
@@ -52,7 +56,33 @@ flatten_chr <- function(.x) {
 
 #' @export
 #' @rdname flatten
-flatten_df <- function(.x, .id = NULL) {
+flatten_raw <- function(.x) {
+  .Call(vflatten_impl, .x, "raw")
+}
+
+#' @export
+#' @rdname flatten
+flatten_dfr <- function(.x, .id = NULL) {
+  if (!is_installed("dplyr")) {
+    abort("`flatten_dfr()` requires dplyr")
+  }
+
   res <- .Call(flatten_impl, .x)
   dplyr::bind_rows(res, .id = .id)
 }
+
+#' @export
+#' @rdname flatten
+flatten_dfc <- function(.x) {
+  if (!is_installed("dplyr")) {
+    abort("`flatten_dfc()` requires dplyr")
+  }
+
+  res <- .Call(flatten_impl, .x)
+  dplyr::bind_cols(res)
+}
+
+#' @export
+#' @rdname flatten
+#' @usage NULL
+flatten_df <- flatten_dfr
