@@ -5,7 +5,7 @@
 
 /* .Call calls */
 extern SEXP coerce_impl(SEXP, SEXP);
-extern SEXP extract_impl(SEXP, SEXP, SEXP);
+extern SEXP pluck_impl(SEXP, SEXP, SEXP, SEXP);
 extern SEXP flatten_impl(SEXP);
 extern SEXP map_impl(SEXP, SEXP, SEXP, SEXP);
 extern SEXP map2_impl(SEXP, SEXP, SEXP, SEXP, SEXP);
@@ -15,7 +15,7 @@ extern SEXP vflatten_impl(SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"coerce_impl",    (DL_FUNC) &coerce_impl,    2},
-    {"extract_impl",   (DL_FUNC) &extract_impl,   3},
+    {"pluck_impl",   (DL_FUNC) &pluck_impl,   4},
     {"flatten_impl",   (DL_FUNC) &flatten_impl,   1},
     {"map_impl",       (DL_FUNC) &map_impl,       4},
     {"map2_impl",      (DL_FUNC) &map2_impl,      5},
