@@ -4,7 +4,7 @@ test_that("long format corresponds to expand.grid output", {
   x <- list(a = 1:3, b = 4:9)
 
   out1 <- cross_df(x)
-  out2 <- expand.grid(x, KEEP.OUT.ATTRS = FALSE) %>% dplyr::as_data_frame()
+  out2 <- expand.grid(x, KEEP.OUT.ATTRS = FALSE) %>% tibble::as_tibble()
 
   expect_equal(out1, out2)
 })
@@ -15,6 +15,10 @@ test_that("filtering works", {
   expect_equal(out, list(list(1, 2), list(1, 3), list(2, 3)))
 })
 
+test_that("filtering requires a predicate function", {
+  expect_error(cross2(1:3, 1:3, .filter = ~ c(TRUE, TRUE)), "not a logical vector of length 2")
+})
+
 test_that("filtering fails when filter function doesn't return a logical", {
   filter <- function(x, y, z) x + y + z
   expect_error(cross3(1:3, 1:3, 1:3, .filter = filter))
