@@ -36,3 +36,15 @@ test_that("quietly captures output", {
 test_that("possibly returns default value on failure", {
   expect_identical(possibly(log, NA_real_)("a"), NA_real_)
 })
+
+test_that("possibly emits a message on failure if quiet = FALSE", {
+  f <- function(...) stop("tilt")
+  expect_message({
+    possibly(f, NA_real_, quiet = FALSE)()
+  }, regexp = "tilt")
+})
+
+test_that("auto_browse() not intended for primitive functions", {
+  expect_error(auto_browse(log)(NULL), "primitive functions")
+  expect_error(auto_browse(identity)(NULL), NA)
+})
